==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klateditwidgetmanager.cpp <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klateditwidgetmanager.h"
#include <klibloader.h>
#include <kpluginfactory.h>
#include <kmessagebox.h>
#include <ktexteditor/document.h>
#include <ktexteditor/editor.h>
#include <ktexteditor/editorchooser.h>

KlatEditWidgetManager *KlatEditWidgetManager::inst = 0;

KlatEditWidgetManager *KlatEditWidgetManager::instance()
{
	if (inst != 0)
		return inst;
	inst =  new KlatEditWidgetManager();
	return inst;
}

KlatEditWidgetManager::KlatEditWidgetManager()
{
//	plugin = 0;
}

KlatEditWidgetManager::~KlatEditWidgetManager()
{
	// this should never be called...
}

KTextEditor::Document *KlatEditWidgetManager::createDocument()
{
    
	KTextEditor::Document *d;
	
	KTextEditor::Editor *editor = KTextEditor::EditorChooser::editor();
	if (!editor) {
		KMessageBox::error(0, "A KDE text-editor component could not be found;\n please check your KDE installation.");
	} else
	d = editor->createDocument(0);
/*	if(plugin == 0)
	    plugin = new KPluginLoader("katepart");
	if(!plugin)								     
	    KMessageBox::error(0,plugin->errorString());
	else
	{
	    KPluginFactory * factory=plugin->factory();
	    if(factory->componentData().isValid());
	    else
	    KMessageBox::error(0,factory->componentData().componentName());
//	    d = factory->create<KTextEditor::Document>("KTextEditor::Document");
	}*/
	docs.push_front(d);
	return d;
}

void KlatEditWidgetManager::destroyDocument(KTextEditor::Document *d)
{
	std::list<KTextEditor::Document *>::iterator it;
	bool found;
	
	found = false;
	it = docs.begin();
	while (!found && it != docs.end())
	{
		if ((*it) == d)
			found = true;
		else
			++it;
	}
	
	if (!found)
		return;

	docs.erase(it);
	delete d;
	
	if (docs.empty())
	{
//		delete plugin;
//		plugin = 0;
	}
}

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klateditwidgetmanager.cpp <==
/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klateditwidgetmanager.h"

#include <KMessageBox>
#include <KLocalizedString>
#include <KTextEditor/Document>
#include <KTextEditor/Editor>
#include <KTextEditor/EditorChooser>

KlatEditWidgetManager *KlatEditWidgetManager::inst = 0;

KlatEditWidgetManager *KlatEditWidgetManager::instance()
{
	if (inst != 0)
		return inst;
	inst =  new KlatEditWidgetManager();
	return inst;
}

KlatEditWidgetManager::KlatEditWidgetManager()
{
}

KlatEditWidgetManager::~KlatEditWidgetManager()
{
	// this should never be called...
}

KTextEditor::Document *KlatEditWidgetManager::createDocument()
{
    
	KTextEditor::Document *d;
	
	KTextEditor::Editor *editor = KTextEditor::EditorChooser::editor();
	if (!editor) {
		KMessageBox::error(0, i18n("A KDE text-editor component could not be found;\n please check your KDE installation."));
	} else
	d = editor->createDocument(0);
	docs.append(d);
	return d;
}

void KlatEditWidgetManager::destroyDocument(KTextEditor::Document *d)
{
	QList<KTextEditor::Document *>::iterator it;
	bool found;
	
	found = false;
	it = docs.begin();
	while (!found && it != docs.end())
	{
		if ((*it) == d)
			found = true;
		else
			++it;
	}
	
	if (!found)
		return;

	docs.erase(it);
	delete d;
}
